@@ -72,7 +72,7 @@ from pymc.distributions.shape_utils import (
 from pymc.distributions.transforms import Interval, ZeroSumTransform, _default_transform
 from pymc.logprob.abstract import _logprob
 from pymc.math import kron_diag, kron_dot
-from pymc.pytensorf import intX, normalize_rng_param
+from pymc.pytensorf import normalize_rng_param
 from pymc.util import check_dist_not_registered
 
 __all__ = [
@@ -929,7 +929,7 @@ class Wishart(Continuous):
 
     @classmethod
     def dist(cls, nu, V, *args, **kwargs):
-        nu = pt.as_tensor_variable(intX(nu))
+        nu = pt.as_tensor_variable(nu, dtype=int)
         V = pt.as_tensor_variable(V)
 
         warnings.warn(
@@ -1047,11 +1047,11 @@ def WishartBartlett(name, S, nu, is_cholesky=False, return_cholesky=False, initv
         tril_testval = None
 
     c = pt.sqrt(
-        ChiSquared("%s_c" % name, nu - np.arange(2, 2 + n_diag), shape=n_diag, initval=diag_testval)
+        ChiSquared(f"{name}_c", nu - np.arange(2, 2 + n_diag), shape=n_diag, initval=diag_testval)
     )
-    pm._log.info("Added new variable %s_c to model diagonal of Wishart." % name)
-    z = Normal("%s_z" % name, 0.0, 1.0, shape=n_tril, initval=tril_testval)
-    pm._log.info("Added new variable %s_z to model off-diagonals of Wishart." % name)
+    pm._log.info(f"Added new variable {name}_c to model diagonal of Wishart.")
+    z = Normal(f"{name}_z", 0.0, 1.0, shape=n_tril, initval=tril_testval)
+    pm._log.info(f"Added new variable {name}_z to model off-diagonals of Wishart.")
     # Construct A matrix
     A = pt.zeros(S.shape, dtype=np.float32)
     A = pt.set_subtensor(A[diag_idx], c)
@@ -2454,7 +2454,7 @@ class StickBreakingWeightsRV(RandomVariable):
 
     def make_node(self, rng, size, dtype, alpha, K):
         alpha = pt.as_tensor_variable(alpha)
-        K = pt.as_tensor_variable(intX(K))
+        K = pt.as_tensor_variable(K, dtype=int)
 
         if K.ndim > 0:
             raise ValueError("K must be a scalar.")
