@@ -13,6 +13,8 @@
 #   limitations under the License.
 
 
+from functools import partial
+
 from pytensor.compile import SharedVariable
 from pytensor.graph.basic import Constant, walk
 from pytensor.tensor.basic import TensorVariable, Variable
@@ -55,7 +57,7 @@ def str_for_dist(
 
     if "latex" in formatting:
         if print_name is not None:
-            print_name = r"\text{" + _latex_escape(dist.name.strip("$")) + "}"
+            print_name = r"\text{" + _latex_escape(print_name.strip("$")) + "}"
 
         op_name = (
             dist.owner.op._print_name[1]
@@ -63,12 +65,11 @@ def str_for_dist(
             else r"\\operatorname{Unknown}"
         )
         if include_params:
+            params = ",~".join([d.strip("$") for d in dist_args])
             if print_name:
-                return r"${} \sim {}({})$".format(
-                    print_name, op_name, ",~".join([d.strip("$") for d in dist_args])
-                )
+                return rf"${print_name} \sim {op_name}({params})$"
             else:
-                return r"${}({})$".format(op_name, ",~".join([d.strip("$") for d in dist_args]))
+                return rf"${op_name}({params})$"
 
         else:
             if print_name:
@@ -81,10 +82,11 @@ def str_for_dist(
             dist.owner.op._print_name[0] if hasattr(dist.owner.op, "_print_name") else "Unknown"
         )
         if include_params:
+            params = ", ".join(dist_args)
             if print_name:
-                return r"{} ~ {}({})".format(print_name, dist_name, ", ".join(dist_args))
+                return rf"{print_name} ~ {dist_name}({params})"
             else:
-                return r"{}({})".format(dist_name, ", ".join(dist_args))
+                return rf"{dist_name}({params})"
         else:
             if print_name:
                 return rf"{print_name} ~ {dist_name}"
@@ -96,17 +98,16 @@ def str_for_model(model: Model, formatting: str = "plain", include_params: bool
     """Make a human-readable string representation of Model, listing all random variables
     and their distributions, optionally including parameter values."""
 
-    kwargs = dict(formatting=formatting, include_params=include_params)
-    free_rv_reprs = [str_for_dist(dist, **kwargs) for dist in model.free_RVs]
-    observed_rv_reprs = [str_for_dist(rv, **kwargs) for rv in model.observed_RVs]
-    det_reprs = [
-        str_for_potential_or_deterministic(dist, **kwargs, dist_name="Deterministic")
-        for dist in model.deterministics
-    ]
-    potential_reprs = [
-        str_for_potential_or_deterministic(pot, **kwargs, dist_name="Potential")
-        for pot in model.potentials
-    ]
+    # Wrap functions to avoid confusing typecheckers
+    sfd = partial(str_for_dist, formatting=formatting, include_params=include_params)
+    sfp = partial(
+        str_for_potential_or_deterministic, formatting=formatting, include_params=include_params
+    )
+
+    free_rv_reprs = [sfd(dist) for dist in model.free_RVs]
+    observed_rv_reprs = [sfd(rv) for rv in model.observed_RVs]
+    det_reprs = [sfp(dist, dist_name="Deterministic") for dist in model.deterministics]
+    potential_reprs = [sfp(pot, dist_name="Potential") for pot in model.potentials]
 
     var_reprs = free_rv_reprs + det_reprs + observed_rv_reprs + potential_reprs
 
@@ -162,6 +163,8 @@ def _str_for_input_var(var: Variable, formatting: str) -> str:
     from pymc.distributions.distribution import SymbolicRandomVariable
 
     def _is_potential_or_deterministic(var: Variable) -> bool:
+        if not hasattr(var, "str_repr"):
+            return False
         try:
             return var.str_repr.__func__.func is str_for_potential_or_deterministic
         except AttributeError:
@@ -175,6 +178,7 @@ def _str_for_input_var(var: Variable, formatting: str) -> str:
     ) or _is_potential_or_deterministic(var):
         # show the names for RandomVariables, Deterministics, and Potentials, rather
         # than the full expression
+        assert isinstance(var, TensorVariable)
         return _str_for_input_rv(var, formatting)
     elif isinstance(var.owner.op, DimShuffle):
         return _str_for_input_var(var.owner.inputs[0], formatting)
@@ -182,7 +186,7 @@ def _str_for_input_var(var: Variable, formatting: str) -> str:
         return _str_for_expression(var, formatting)
 
 
-def _str_for_input_rv(var: Variable, formatting: str) -> str:
+def _str_for_input_rv(var: TensorVariable, formatting: str) -> str:
     _str = (
         var.name
         if var.name is not None
@@ -221,12 +225,15 @@ def _str_for_expression(var: Variable, formatting: str) -> str:
         if x.owner and (not isinstance(x.owner.op, RandomVariable | SymbolicRandomVariable)):
             return reversed(x.owner.inputs)
 
-    parents = [
-        x
-        for x in walk(nodes=var.owner.inputs, expand=_expand)
-        if x.owner and isinstance(x.owner.op, RandomVariable | SymbolicRandomVariable)
-    ]
-    names = [x.name for x in parents]
+    parents = []
+    names = []
+    for x in walk(nodes=var.owner.inputs, expand=_expand):
+        assert isinstance(x, Variable)
+        if x.owner and isinstance(x.owner.op, RandomVariable | SymbolicRandomVariable):
+            parents.append(x)
+            xname = x.name
+            assert xname is not None
+            names.append(xname)
 
     if "latex" in formatting:
         return (
@@ -257,6 +264,8 @@ def _default_repr_pretty(obj: TensorVariable | Model, p, cycle):
     """Handy plug-in method to instruct IPython-like REPLs to use our str_repr above."""
     # we know that our str_repr does not recurse, so we can ignore cycle
     try:
+        if not hasattr(obj, "str_repr"):
+            raise AttributeError
         output = obj.str_repr()
         # Find newlines and replace them with p.break_()
         # (see IPython.lib.pretty._repr_pprint)
