@@ -44,7 +44,7 @@ from pytensor.tensor.random.var import (
 )
 from pytensor.tensor.sharedvar import SharedVariable
 from rich.console import Console
-from rich.progress import Progress
+from rich.progress import BarColumn, TextColumn, TimeElapsedColumn, TimeRemainingColumn
 from rich.theme import Theme
 
 import pymc as pm
@@ -55,6 +55,7 @@ from pymc.blocking import PointType
 from pymc.model import Model, modelcontext
 from pymc.pytensorf import compile_pymc
 from pymc.util import (
+    CustomProgress,
     RandomState,
     _get_seeds_per_chain,
     default_progress_theme,
@@ -418,7 +419,7 @@ def sample_prior_predictive(
 
     data = {k: np.stack(v) for k, v in zip(names, values)}
     if data is None:
-        raise AssertionError("No variables sampled: attempting to sample %s" % names)
+        raise AssertionError(f"No variables sampled: attempting to sample {names}")
 
     prior: dict[str, np.ndarray] = {}
     for var_name in vars_:
@@ -764,8 +765,7 @@ def sample_posterior_predictive(
         samples = len(_trace)
     else:
         raise TypeError(
-            "Do not know how to compute number of samples for trace argument of type %s"
-            % type(_trace)
+            f"Do not know how to compute number of samples for trace argument of type {type(_trace)}"
         )
 
     assert samples is not None
@@ -828,11 +828,21 @@ def sample_posterior_predictive(
     # All model variables have a name, but mypy does not know this
     _log.info(f"Sampling: {list(sorted(volatile_basic_rvs, key=lambda var: var.name))}")  # type: ignore
     ppc_trace_t = _DefaultTrace(samples)
+
+    progress = CustomProgress(
+        "[progress.description]{task.description}",
+        BarColumn(),
+        "[progress.percentage]{task.percentage:>3.0f}%",
+        TimeRemainingColumn(),
+        TextColumn("/"),
+        TimeElapsedColumn(),
+        console=Console(theme=progressbar_theme),
+        disable=not progressbar,
+    )
+
     try:
-        with Progress(
-            console=Console(theme=progressbar_theme), disable=not progressbar
-        ) as progress:
-            task = progress.add_task("Sampling ...", total=samples, visible=progressbar)
+        with progress:
+            task = progress.add_task("Sampling ...", completed=0, total=samples)
             for idx in np.arange(samples):
                 if nchain > 1:
                     # the trace object will either be a MultiTrace (and have _straces)...
@@ -854,6 +864,7 @@ def sample_posterior_predictive(
                     ppc_trace_t.insert(k.name, v, idx)
 
                 progress.advance(task)
+            progress.update(task, refresh=True, completed=samples)
 
     except KeyboardInterrupt:
         pass
