@@ -6,6 +6,7 @@ run by the other jobs.
 This is intended to be used as a pre-commit hook, see `.pre-commit-config.yaml`.
 You can run it manually with `pre-commit run check-no-tests-are-ignored --all`.
 """
+
 import itertools
 import logging
 import os
@@ -69,14 +70,14 @@ def from_yaml():
         for os_, floatX, subset in itertools.product(
             matrix["os"], matrix["floatx"], matrix["test-subset"]
         ):
-            lines = [l for l in subset.split("\n") if l]
+            lines = [k for k in subset.split("\n") if k]
             if "windows" in os_:
                 # Windows jobs need \ in line breaks within the test-subset!
                 # The following checks that these trailing \ are present in
                 # all items except the last.
                 if lines and lines[-1].endswith(" \\"):
                     raise Exception(
-                        f"Last entry '{line}' in Windows test subset should end WITHOUT ' \\'."
+                        f"Last entry '{lines}' in Windows test subset should end WITHOUT ' \\'."
                     )
                 for line in lines[:-1]:
                     if not line.endswith(" \\"):
