@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -34,7 +34,6 @@
 #   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 #   SOFTWARE.
 
-from typing import Optional
 
 import numpy as np
 
@@ -51,7 +50,7 @@ def scipy_logprob(obs, p):
         elif p.ndim < obs.ndim:
             p = p[((None,) * (obs.ndim - p.ndim) + (Ellipsis,))]
 
-        pattern = (p.ndim - 1,) + tuple(range(p.ndim - 1))
+        pattern = (p.ndim - 1, *range(p.ndim - 1))
         return np.log(np.take_along_axis(p.transpose(pattern), obs, 0))
     else:
         return np.log(p[obs])
